==> vue-user-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/user/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import Select from "@dftvue2-opentiny/vue-select";
import Option from "@dftvue2-opentiny/vue-option";
import { iconUser, iconGroup } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinySelect: Select,
    TinyOption: Option,
    IconUser: iconUser(),
    IconGroup: iconGroup()
  },
  inheritAttrs: false,
  emits: ["blur", "focus", "change", "error", "visible-change", "update:modelValue"],
  props: [].concat(props, ["modelValue", "multiple", "size", "displayOnly", "disabled", "sortable", "valueSplit", "textSplit", "valueField", "textField", "collapseTags", "showOverflowTooltip", "placeholder", "cache", "delay", "suggestLength", "cacheFields", "cacheKey", "UserCache", "fetchW3Accounts", "fetchUserByUserId", "fetchSuggestUser", "sortByFetchData", "popperClass", "popperAppendToBody", "tabindex", "tagSelectable", "copyable", "batch", "allowCopy", "noDataText", "loadingText", "autoClose", "queryDebounce", "hideSelected", "ignoreEnter", "showTips", "maxWidth"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-user",
    on: {
      "mouseover": _vm.useSortable
    }
  }, [_c("tiny-select", _vm._b({
    ref: "select",
    staticClass: "tiny-user__select",
    attrs: {
      "popper-class": "tiny-user" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "display-only": _vm.displayOnly,
      "disabled": _vm.disabled,
      "show-overflow-tooltip": _vm.showOverflowTooltip,
      "hide-drop": !_vm.state.visible,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "collapse-tags": _vm.collapseTags,
      "multiple": _vm.multiple,
      "loading": _vm.state.loading,
      "filterable": "",
      "clearable": "",
      "remote": "",
      "remote-method": _vm.searchMethod,
      "tabindex": _vm.tabindex,
      "tag-selectable": _vm.tagSelectable,
      "copyable": _vm.copyable,
      "allow-copy": _vm.allowCopy,
      "text-split": _vm.textSplit,
      "loading-text": _vm.loadingText,
      "no-data-text": _vm.noDataText,
      "auto-close": _vm.autoClose,
      "query-debounce": _vm.queryDebounce,
      "ignore-enter": _vm.ignoreEnter,
      "show-tips": _vm.showTips
    },
    on: {
      "blur": _vm.handleBlur,
      "focus": function focus($event) {
        return _vm.$emit("focus", $event);
      },
      "change": _vm.userChange,
      "visible-change": _vm.visibleChange,
      "clear": function clear($event) {
        return _vm.$parent.$emit("clear");
      }
    },
    scopedSlots: _vm._u([{
      key: "prefix",
      fn: function fn() {
        return [_c("div", [_vm.multiple ? _c("icon-group", {
          staticClass: "tiny-svg-size"
        }) : _c("icon-user", {
          staticClass: "tiny-svg-size"
        })], 1)];
      },
      proxy: true
    }, _vm.slots.label ? {
      key: "label",
      fn: function fn(_ref) {
        var item = _ref.item;
        return [_vm._t("label", null, {
          "user": item
        })];
      }
    } : null], null, true),
    model: {
      value: _vm.state.user,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "user", $$v);
      },
      expression: "state.user"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.filter(), function(option) {
    return _c("tiny-option", {
      key: option[_vm.valueField],
      staticClass: "tiny-user__select-dropdown",
      attrs: {
        "title": option.userCN + (option.dept ? " " + option.dept : ""),
        "visible": option._show,
        "label": option[_vm.textField],
        "value": option[_vm.valueField]
      }
    }, [_vm._t("options", function() {
      return [_c("span", {
        staticClass: "tiny-user_select left"
      }, [_vm._v(_vm._s(option.userCN))]), _c("span", {
        staticClass: "tiny-user_select right"
      }, [_vm._v(_vm._s(option.dept))])];
    }, {
      "slotScope": option
    })], 2);
  }), 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-user-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/user/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Select from '@opentinyvue/vue-select';
import Option from '@opentinyvue/vue-option';
import { iconUser, iconGroup } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinySelect: Select,
    TinyOption: Option,
    IconUser: iconUser(),
    IconGroup: iconGroup()
  },
  inheritAttrs: false,
  emits: ["blur", "focus", "change", "error", "visible-change", "update:modelValue"],
  props: [].concat(props, ["modelValue", "multiple", "size", "displayOnly", "disabled", "sortable", "valueSplit", "textSplit", "valueField", "textField", "collapseTags", "showOverflowTooltip", "placeholder", "cache", "delay", "suggestLength", "cacheFields", "cacheKey", "UserCache", "fetchW3Accounts", "fetchUserByUserId", "fetchSuggestUser", "sortByFetchData", "popperClass", "popperAppendToBody", "tabindex", "tagSelectable", "copyable", "batch", "allowCopy", "noDataText", "loadingText", "autoClose", "queryDebounce", "hideSelected", "ignoreEnter", "showTips", "maxWidth", "keepFocus", "changeCompat", "multiLineDrag", "multipleLimit"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-user",
    class: _vm.multiLineDrag ? "draggableClass" : "",
    on: {
      "mouseover": _vm.useSortable
    }
  }, [_c("tiny-select", _vm._b({
    ref: "select",
    staticClass: "tiny-user__select",
    attrs: {
      "popper-class": "tiny-user" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "display-only": _vm.displayOnly,
      "disabled": _vm.disabled,
      "show-overflow-tooltip": _vm.showOverflowTooltip,
      "hide-drop": !_vm.state.visible,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "collapse-tags": _vm.collapseTags,
      "multiple": _vm.multiple,
      "multipleLimit": _vm.multipleLimit,
      "loading": _vm.state.loading,
      "filterable": "",
      "clearable": "",
      "remote": "",
      "remote-method": _vm.searchMethod,
      "tabindex": _vm.tabindex,
      "tag-selectable": _vm.tagSelectable,
      "copyable": _vm.copyable,
      "allow-copy": _vm.allowCopy,
      "text-split": _vm.textSplit,
      "loading-text": _vm.loadingText,
      "no-data-text": _vm.noDataText,
      "auto-close": _vm.autoClose,
      "query-debounce": _vm.queryDebounce,
      "ignore-enter": _vm.ignoreEnter,
      "show-tips": _vm.showTips,
      "keep-focus": _vm.keepFocus
    },
    on: {
      "blur": _vm.handleBlur,
      "focus": function focus($event) {
        return _vm.$emit("focus", $event);
      },
      "change": _vm.userChange,
      "visible-change": _vm.visibleChange,
      "clear": function clear($event) {
        return _vm.$parent.$emit("clear");
      }
    },
    scopedSlots: _vm._u([{
      key: "prefix",
      fn: function fn() {
        return [_c("div", [_vm.multiple ? _c("icon-group", {
          staticClass: "tiny-svg-size"
        }) : _c("icon-user", {
          staticClass: "tiny-svg-size"
        })], 1)];
      },
      proxy: true
    }, _vm.slots.label ? {
      key: "label",
      fn: function fn(_ref) {
        var item = _ref.item;
        return [_vm._t("label", null, {
          "user": item
        })];
      }
    } : null], null, true),
    model: {
      value: _vm.state.user,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "user", $$v);
      },
      expression: "state.user"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.filter(), function(option) {
    return _c("tiny-option", {
      key: option[_vm.state.valueField],
      staticClass: "tiny-user__select-dropdown",
      attrs: {
        "title": option[_vm.state.textField] + (option.dept ? " " + option.dept : ""),
        "visible": option._show,
        "label": option[_vm.state.textField],
        "value": option[_vm.state.valueField]
      }
    }, [_vm._t("options", function() {
      return [_c("span", {
        staticClass: "tiny-user_select left"
      }, [_vm._v(_vm._s(option[_vm.state.textField]))]), _c("span", {
        staticClass: "tiny-user_select right"
      }, [_vm._v(_vm._s(option.dept))])];
    }, {
      "slotScope": option
    })], 2);
  }), 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
